#!/bin/sh

# LOG_LEVEL
#   0  Only fatal error messages
#   1  Description of the current process
#   2  Solvers iterations are shown (default)
export LOG_LEVEL=2

# SOLVER_TYPE
# Chooses solver for all session
#   1  Conjugate gradient (default)
#   2  Cholesky decomposition
#   3  Cholesky2 decomposition
#   4  Biconjugate gradient
#   5  LU decomposition
export SOLVER_TYPE=1

# SOLVER_THREADS
# Sets the maximum number of threads used by solvers
export SOLVER_THREADS=1

# SOLVER_TOLERANCE
# For iterative solvers, this defines the convergence criteria
export SOLVER_TOLERANCE=1e-5

# SOLVER_MAX_STEPS
# For iterative solvers, it is the maximum number of iterations allowed
export SOLVER_MAX_STEPS=10000

# PRECONDITIONER_TYPE
# For iterative solvers.
#   0=None
#   1=Jacobi (default)
#   2=Incomplete_Cholesky (Only for Conjugate gradient)
#   3=Incomplete_Cholesky2 (Only for Conjugate gradient)
#   4=Incomplete_LU (Only for Biconjugate gradient)
#   5=Sparse_Approximate_Inverse
export PRECONDITIONER_TYPE=1

# PRECONDITIONER_LEVEL
# Set the preconditioner level for Incomplete_Cholesky, Incomplete_Cholesky2, Incomplete_LU and Sparse_Approximate_Inverse
export PRECONDITIONER_LEVEL=1

# PRECONDITIONER_THRESHOLD
# Set the preconditioner threshold for Sparse_Approximate_Inverse
export PRECONDITIONER_THRESHOLD=0.0

# SUBSTRUCTURING_THREADS
# Number of threads used in the master to assemble matrices
export SUBSTRUCTURING_THREADS=1

# SUBSTRUCTURING_TOLERANCE
# Tolerance for convergence of Schur matrix
export SUBSTRUCTURING_TOLERANCE=1e-5

named_pipe_data="FEMData"
named_pipe_result="FEMResult"

# PROCESSES
export processes=3

mpiexec -x LOG_LEVEL -x SOLVER_TYPE -x SOLVER_THREADS -x SOLVER_TOLERANCE -x SOLVER_MAX_STEPS -x PRECONDITIONER_TYPE -x PRECONDITIONER_LEVEL -x PRECONDITIONER_THRESHOLD -x SUBSTRUCTURING_THREADS -x SUBSTRUCTURING_TOLERANCE -n $processes FEMSolver.MPI $named_pipe_data $named_pipe_result
